Documentation
¶
Index ¶
- func LoadBuiltins(syncReq chan struct{}) chan types.PluginUpdateResponse
- type Config
- type ID
- type Node
- func (n *Node) Close() error
- func (n *Node) Connect(ctx context.Context) error
- func (n *Node) Handshake(ctx context.Context) error
- func (n *Node) KeepPluginsUpToDate(ctxMetadata context.Context, specsSync chan struct{})
- func (n *Node) KillPlugins()
- func (n *Node) ListenTaskRequest(ctx context.Context) error
- func (n *Node) NodePlugins(ctx context.Context) (map[string]string, error)
- type SpecsManager
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func LoadBuiltins ¶
func LoadBuiltins(syncReq chan struct{}) chan types.PluginUpdateResponse
Types ¶
type Config ¶
type Config struct {
ManagerAddress string
ManagerPort string
NodeID string
MTLSEnabled bool
MTLSCert string
MTLSKey string
MTLSManagerCA string
PluginDir string
PluginServerPort string
CustomResolvers []string
MaxConcurrentTasks int
MaxWaitingRequests int
}
Config holds the configuration for creating a new Node.
type Node ¶
type Node struct {
SpecManager *SpecsManager
// contains filtered or unexported fields
}
func New ¶
New returns a new Node and an initialized context containing values like node_id.
While the node is the client from GRPC perspective, it is the server from application perspective, i.e. the manager (GRPC server) sends requests to the node (GRPC client) via a bidi GRPC stream.
func (*Node) KeepPluginsUpToDate ¶
func (*Node) KillPlugins ¶
func (n *Node) KillPlugins()
type SpecsManager ¶
type SpecsManager struct {
// contains filtered or unexported fields
}
func NewSpecsManager ¶
func NewSpecsManager() (*SpecsManager, error)
func (*SpecsManager) List ¶
func (s *SpecsManager) List() ([]string, error)
func (*SpecsManager) StartSpecCollector ¶
func (s *SpecsManager) StartSpecCollector(ctx context.Context, syncReq chan struct{})
Click to show internal directories.
Click to hide internal directories.